@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.0.5.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -101,49 +101,57 @@ extern int yydebug;
     VAR_UDP = 311,
     VAR_VERBOSITY = 312,
     VAR_HIDE_VERSION = 313,
-    VAR_PATTERN = 314,
-    VAR_INCLUDEPATTERN = 315,
-    VAR_ZONELISTFILE = 316,
-    VAR_REMOTE_CONTROL = 317,
-    VAR_CONTROL_ENABLE = 318,
-    VAR_CONTROL_INTERFACE = 319,
-    VAR_CONTROL_PORT = 320,
-    VAR_SERVER_KEY_FILE = 321,
-    VAR_SERVER_CERT_FILE = 322,
-    VAR_CONTROL_KEY_FILE = 323,
-    VAR_CONTROL_CERT_FILE = 324,
-    VAR_XFRDIR = 325,
-    VAR_RRL_SIZE = 326,
-    VAR_RRL_RATELIMIT = 327,
-    VAR_RRL_SLIP = 328,
-    VAR_RRL_IPV4_PREFIX_LENGTH = 329,
-    VAR_RRL_IPV6_PREFIX_LENGTH = 330,
-    VAR_RRL_WHITELIST_RATELIMIT = 331,
-    VAR_RRL_WHITELIST = 332,
-    VAR_ZONEFILES_CHECK = 333,
-    VAR_ZONEFILES_WRITE = 334,
-    VAR_LOG_TIME_ASCII = 335,
-    VAR_ROUND_ROBIN = 336,
-    VAR_ZONESTATS = 337,
-    VAR_REUSEPORT = 338,
-    VAR_VERSION = 339,
-    VAR_MAX_REFRESH_TIME = 340,
-    VAR_MIN_REFRESH_TIME = 341,
-    VAR_MAX_RETRY_TIME = 342,
-    VAR_MIN_RETRY_TIME = 343,
-    VAR_MULTI_MASTER_CHECK = 344,
-    VAR_MINIMAL_RESPONSES = 345,
-    VAR_REFUSE_ANY = 346,
-    VAR_USE_SYSTEMD = 347,
-    VAR_DNSTAP = 348,
-    VAR_DNSTAP_ENABLE = 349,
-    VAR_DNSTAP_SOCKET_PATH = 350,
-    VAR_DNSTAP_SEND_IDENTITY = 351,
-    VAR_DNSTAP_SEND_VERSION = 352,
-    VAR_DNSTAP_IDENTITY = 353,
-    VAR_DNSTAP_VERSION = 354,
-    VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES = 355,
-    VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES = 356
+    VAR_HIDE_IDENTITY = 314,
+    VAR_PATTERN = 315,
+    VAR_INCLUDEPATTERN = 316,
+    VAR_ZONELISTFILE = 317,
+    VAR_REMOTE_CONTROL = 318,
+    VAR_CONTROL_ENABLE = 319,
+    VAR_CONTROL_INTERFACE = 320,
+    VAR_CONTROL_PORT = 321,
+    VAR_SERVER_KEY_FILE = 322,
+    VAR_SERVER_CERT_FILE = 323,
+    VAR_CONTROL_KEY_FILE = 324,
+    VAR_CONTROL_CERT_FILE = 325,
+    VAR_XFRDIR = 326,
+    VAR_RRL_SIZE = 327,
+    VAR_RRL_RATELIMIT = 328,
+    VAR_RRL_SLIP = 329,
+    VAR_RRL_IPV4_PREFIX_LENGTH = 330,
+    VAR_RRL_IPV6_PREFIX_LENGTH = 331,
+    VAR_RRL_WHITELIST_RATELIMIT = 332,
+    VAR_RRL_WHITELIST = 333,
+    VAR_ZONEFILES_CHECK = 334,
+    VAR_ZONEFILES_WRITE = 335,
+    VAR_LOG_TIME_ASCII = 336,
+    VAR_ROUND_ROBIN = 337,
+    VAR_ZONESTATS = 338,
+    VAR_REUSEPORT = 339,
+    VAR_VERSION = 340,
+    VAR_MAX_REFRESH_TIME = 341,
+    VAR_MIN_REFRESH_TIME = 342,
+    VAR_MAX_RETRY_TIME = 343,
+    VAR_MIN_RETRY_TIME = 344,
+    VAR_MULTI_MASTER_CHECK = 345,
+    VAR_MINIMAL_RESPONSES = 346,
+    VAR_REFUSE_ANY = 347,
+    VAR_USE_SYSTEMD = 348,
+    VAR_DNSTAP = 349,
+    VAR_DNSTAP_ENABLE = 350,
+    VAR_DNSTAP_SOCKET_PATH = 351,
+    VAR_DNSTAP_SEND_IDENTITY = 352,
+    VAR_DNSTAP_SEND_VERSION = 353,
+    VAR_DNSTAP_IDENTITY = 354,
+    VAR_DNSTAP_VERSION = 355,
+    VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES = 356,
+    VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES = 357,
+    VAR_TLS_SERVICE_KEY = 358,
+    VAR_TLS_SERVICE_OCSP = 359,
+    VAR_TLS_SERVICE_PEM = 360,
+    VAR_TLS_PORT = 361,
+    VAR_SEND_BUFFER_SIZE = 362,
+    VAR_RECEIVE_BUFFER_SIZE = 363,
+    VAR_TCP_REJECT_OVERFLOW = 364
   };
 #endif
 /* Tokens.  */
@@ -203,60 +211,68 @@ extern int yydebug;
 #define VAR_UDP 311
 #define VAR_VERBOSITY 312
 #define VAR_HIDE_VERSION 313
-#define VAR_PATTERN 314
-#define VAR_INCLUDEPATTERN 315
-#define VAR_ZONELISTFILE 316
-#define VAR_REMOTE_CONTROL 317
-#define VAR_CONTROL_ENABLE 318
-#define VAR_CONTROL_INTERFACE 319
-#define VAR_CONTROL_PORT 320
-#define VAR_SERVER_KEY_FILE 321
-#define VAR_SERVER_CERT_FILE 322
-#define VAR_CONTROL_KEY_FILE 323
-#define VAR_CONTROL_CERT_FILE 324
-#define VAR_XFRDIR 325
-#define VAR_RRL_SIZE 326
-#define VAR_RRL_RATELIMIT 327
-#define VAR_RRL_SLIP 328
-#define VAR_RRL_IPV4_PREFIX_LENGTH 329
-#define VAR_RRL_IPV6_PREFIX_LENGTH 330
-#define VAR_RRL_WHITELIST_RATELIMIT 331
-#define VAR_RRL_WHITELIST 332
-#define VAR_ZONEFILES_CHECK 333
-#define VAR_ZONEFILES_WRITE 334
-#define VAR_LOG_TIME_ASCII 335
-#define VAR_ROUND_ROBIN 336
-#define VAR_ZONESTATS 337
-#define VAR_REUSEPORT 338
-#define VAR_VERSION 339
-#define VAR_MAX_REFRESH_TIME 340
-#define VAR_MIN_REFRESH_TIME 341
-#define VAR_MAX_RETRY_TIME 342
-#define VAR_MIN_RETRY_TIME 343
-#define VAR_MULTI_MASTER_CHECK 344
-#define VAR_MINIMAL_RESPONSES 345
-#define VAR_REFUSE_ANY 346
-#define VAR_USE_SYSTEMD 347
-#define VAR_DNSTAP 348
-#define VAR_DNSTAP_ENABLE 349
-#define VAR_DNSTAP_SOCKET_PATH 350
-#define VAR_DNSTAP_SEND_IDENTITY 351
-#define VAR_DNSTAP_SEND_VERSION 352
-#define VAR_DNSTAP_IDENTITY 353
-#define VAR_DNSTAP_VERSION 354
-#define VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES 355
-#define VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES 356
+#define VAR_HIDE_IDENTITY 314
+#define VAR_PATTERN 315
+#define VAR_INCLUDEPATTERN 316
+#define VAR_ZONELISTFILE 317
+#define VAR_REMOTE_CONTROL 318
+#define VAR_CONTROL_ENABLE 319
+#define VAR_CONTROL_INTERFACE 320
+#define VAR_CONTROL_PORT 321
+#define VAR_SERVER_KEY_FILE 322
+#define VAR_SERVER_CERT_FILE 323
+#define VAR_CONTROL_KEY_FILE 324
+#define VAR_CONTROL_CERT_FILE 325
+#define VAR_XFRDIR 326
+#define VAR_RRL_SIZE 327
+#define VAR_RRL_RATELIMIT 328
+#define VAR_RRL_SLIP 329
+#define VAR_RRL_IPV4_PREFIX_LENGTH 330
+#define VAR_RRL_IPV6_PREFIX_LENGTH 331
+#define VAR_RRL_WHITELIST_RATELIMIT 332
+#define VAR_RRL_WHITELIST 333
+#define VAR_ZONEFILES_CHECK 334
+#define VAR_ZONEFILES_WRITE 335
+#define VAR_LOG_TIME_ASCII 336
+#define VAR_ROUND_ROBIN 337
+#define VAR_ZONESTATS 338
+#define VAR_REUSEPORT 339
+#define VAR_VERSION 340
+#define VAR_MAX_REFRESH_TIME 341
+#define VAR_MIN_REFRESH_TIME 342
+#define VAR_MAX_RETRY_TIME 343
+#define VAR_MIN_RETRY_TIME 344
+#define VAR_MULTI_MASTER_CHECK 345
+#define VAR_MINIMAL_RESPONSES 346
+#define VAR_REFUSE_ANY 347
+#define VAR_USE_SYSTEMD 348
+#define VAR_DNSTAP 349
+#define VAR_DNSTAP_ENABLE 350
+#define VAR_DNSTAP_SOCKET_PATH 351
+#define VAR_DNSTAP_SEND_IDENTITY 352
+#define VAR_DNSTAP_SEND_VERSION 353
+#define VAR_DNSTAP_IDENTITY 354
+#define VAR_DNSTAP_VERSION 355
+#define VAR_DNSTAP_LOG_AUTH_QUERY_MESSAGES 356
+#define VAR_DNSTAP_LOG_AUTH_RESPONSE_MESSAGES 357
+#define VAR_TLS_SERVICE_KEY 358
+#define VAR_TLS_SERVICE_OCSP 359
+#define VAR_TLS_SERVICE_PEM 360
+#define VAR_TLS_PORT 361
+#define VAR_SEND_BUFFER_SIZE 362
+#define VAR_RECEIVE_BUFFER_SIZE 363
+#define VAR_TCP_REJECT_OVERFLOW 364
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 
 union YYSTYPE
 {
-#line 42 "configparser.y" /* yacc.c:1909  */
+#line 42 "configparser.y" /* yacc.c:1910  */
 
 	char*	str;
 
-#line 260 "configparser.h" /* yacc.c:1909  */
+#line 276 "configparser.h" /* yacc.c:1910  */
 };
 
 typedef union YYSTYPE YYSTYPE;
